Next Steps — Geraldo Reports Documentation v0.3.6-stable documentation

### Navigation

- index
- previous |
- Geraldo Reports Documentation v0.3.6-stable documentation »

# Next Steps

Geraldo Reports is an ambitious project. We want to provide much more than we have done so far. See below the main goals we have to do in the future (and maybe you could help us to reach them early)

## Engine API

- Table band - a band to make it easy to create lists just using tables instead of detail band and lines. Table band must be an alternative to detail band
- Support canvas draw
- Events (i.e: BeforePrint and AfterPrint for bands and reports)

## Generators

- Generate in ODF formats (ODT and ODS) (currently in development)
- Generate in HTML
- Export/import structure to/from an XML format

## Third-party tools

- Have a GUI tool to design reports, if possible to be used in a web browser
- Have a way to create and print reports using a server, with no low level coding
- Django pluggable application to create fast reports (currently in development)

## Other features

- Charts generation in a easier way
- Cross-reference table
- Barcodes generation
- Maybe a better support to images

### Navigation

- index
- previous |
- Geraldo Reports Documentation v0.3.6-stable documentation »